Skip to contents

Simulated Data Set for DIF M2PL Bifactor Analysis

Usage

D2PL_bifactor_data

Format

A list of components of the data set:

dataItem responses
modelLoading indicators
ndimThe first ndim dimensions are substantive factors, while others are nuisance factors
impactWhether nuisance factors have impact
groupGroup indicators
jIndices of DIF items
paramsA list of true parameters used for generating the item responses:
...$aSlopes
...$bNegated intercepts
...$thetaLatent traits

Author

Yijun Cheng <chengxb@uw.edu>, Weicong Lyu <weiconglyu@um.edu.mo>